@@ -18,7 +18,7 @@
 
 #include "k3bglobals.h"
 
-#include <KConfigCore/KSharedConfig>
+#include <KSharedConfig>
 
 #include <QWidget>
 #include <QLabel>
@@ -44,7 +44,7 @@ namespace K3b {
          * Creates a writerselectionwidget
          */
         explicit WriterSelectionWidget( QWidget* parent = 0 );
-        ~WriterSelectionWidget();
+        ~WriterSelectionWidget() override;
 
         int writerSpeed() const;
         Device::Device* writerDevice() const;
